coordinates - module for coordinate transforms — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# coordinates - module for coordinate transforms

Implementation of Coords class functions for coordinate transformations

Authors: Josef Koller Institution: Los ALamos National Laboratory Contaact: jkoller@lanl.gov

Copyright 2010 Los Alamos National Security, LLC.

`Coords`(data, dtype, carsph, [units, ticks]) | A class holding spatial coordinates in Cartesian/spherical

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »